// ============================================================================
// COPYRIGHT NOTICE
// ----------------------------------------------------------------------------
// (This is the open source ISC license, see
// http://en.wikipedia.org/wiki/ISC_license
// for more info)
//
// Copyright © 2010-2023  Andreas M. Rammelt <rammi@caff.de>
//
// Permission to use, copy, modify, and/or distribute this software for any
// purpose with or without fee is hereby granted, provided that the above
// copyright notice and this permission notice appear in all copies.
//
// THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
// WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
// MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR
// ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
// WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
// ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
// OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
//=============================================================================
// Latest version on https://caff.de/projects/decaff-commons/
//=============================================================================
package de.caff.gimmicks.swing;

import de.caff.annotation.NotNull;

import javax.swing.*;

/**
 * Element of a tool bar.
 * Implementing this interface allows an element to fine tune its
 * addition to the toolbar.
 * @author <a href="mailto:rammi@caff.de">Rammi</a>
 */
public interface ToolBarElement
{
  /**
   * Add this element to the toolbar.
   * @param toolBar toolbar to add to
   * @return components added to toolbar
   */
  @NotNull
  JComponent[] addToToolBar(@NotNull JToolBar toolBar);

  /**
   * Add this element to the toolbar.
   * @param toolBar toolbar to add to
   * @param index   position where to add the item
   * @return actually inserted components
   */
  @NotNull
  JComponent[] addToToolBar(@NotNull JToolBar toolBar, int index);
}
